Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(556)

Unified Diff: talk/session/media/channelmanager.h

Issue 1246913005: TransportController refactoring (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Set media engine on voice channel Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: talk/session/media/channelmanager.h
diff --git a/talk/session/media/channelmanager.h b/talk/session/media/channelmanager.h
index 898ae1cb2db48e0099c144f94b9b98c82be6ac00..bf5a6db218bf723b75926130866b78b263de3e9a 100644
--- a/talk/session/media/channelmanager.h
+++ b/talk/session/media/channelmanager.h
@@ -102,8 +102,9 @@ class ChannelManager : public rtc::MessageHandler,
// The operations below all occur on the worker thread.
- // Creates a voice channel, to be associated with the specified session.
- VoiceChannel* CreateVoiceChannel(BaseSession* session,
+ // Creates a voice channel, to be associated with the specified
+ // TransportController.
+ VoiceChannel* CreateVoiceChannel(TransportController* transport_controller,
const std::string& content_name,
bool rtcp,
const AudioOptions& options);
@@ -111,22 +112,23 @@ class ChannelManager : public rtc::MessageHandler,
void DestroyVoiceChannel(VoiceChannel* voice_channel,
VideoChannel* video_channel);
// TODO(pbos): Remove as soon as all call sites specify VideoOptions.
- VideoChannel* CreateVideoChannel(BaseSession* session,
+ VideoChannel* CreateVideoChannel(TransportController* transport_controller,
const std::string& content_name,
bool rtcp,
VoiceChannel* voice_channel);
// Creates a video channel, synced with the specified voice channel, and
- // associated with the specified session.
- VideoChannel* CreateVideoChannel(BaseSession* session,
+ // associated with the specified TransportController.
+ VideoChannel* CreateVideoChannel(TransportController* transport_controller,
const std::string& content_name,
bool rtcp,
const VideoOptions& options,
VoiceChannel* voice_channel);
// Destroys a video channel created with the Create API.
void DestroyVideoChannel(VideoChannel* video_channel);
- DataChannel* CreateDataChannel(
- BaseSession* session, const std::string& content_name,
- bool rtcp, DataChannelType data_channel_type);
+ DataChannel* CreateDataChannel(TransportController* transport_controller,
+ const std::string& content_name,
+ bool rtcp,
+ DataChannelType data_channel_type);
// Destroys a data channel created with the Create API.
void DestroyDataChannel(DataChannel* data_channel);
@@ -255,21 +257,22 @@ class ChannelManager : public rtc::MessageHandler,
bool InitMediaEngine_w();
void DestructorDeletes_w();
void Terminate_w();
- VoiceChannel* CreateVoiceChannel_w(BaseSession* session,
+ VoiceChannel* CreateVoiceChannel_w(TransportController* transport_controller,
const std::string& content_name,
bool rtcp,
const AudioOptions& options);
void DestroyVoiceChannel_w(VoiceChannel* voice_channel,
VideoChannel* video_channel);
- VideoChannel* CreateVideoChannel_w(BaseSession* session,
+ VideoChannel* CreateVideoChannel_w(TransportController* transport_controller,
const std::string& content_name,
bool rtcp,
const VideoOptions& options,
VoiceChannel* voice_channel);
void DestroyVideoChannel_w(VideoChannel* video_channel);
- DataChannel* CreateDataChannel_w(
- BaseSession* session, const std::string& content_name,
- bool rtcp, DataChannelType data_channel_type);
+ DataChannel* CreateDataChannel_w(TransportController* transport_controller,
+ const std::string& content_name,
+ bool rtcp,
+ DataChannelType data_channel_type);
void DestroyDataChannel_w(DataChannel* data_channel);
bool SetAudioOptions_w(const AudioOptions& options, int delay_offset,
const Device* in_dev, const Device* out_dev);

Powered by Google App Engine
This is Rietveld 408576698